require "thor"
require "date"

class PieceOfWax < Thor
  desc "activity _activity_", "log activity"
  def activity(x)
    write_to_file("#{Time.now} - #{x}")
    puts "wrote #{x} to file"
  end

  desc "read [date]", "print activities on given [date] (yesterday by default)"
  def read(date = Date.today.strftime('%Y-%m-%d'))
    output =
      begin
        generate_output(File.open(filename(date)).readlines)
      rescue Errno::ENOENT
        "Sorry, I couldn't find any logs for #{print_date(date)}."
      end
    puts output
  end

  private

  def write_to_file(str)
    today = Time.now.strftime("%y%m%d")
    File.open("#{today}.txt", "a+") do |f|
      f.puts(str)
    end
  end

  def filename(date)
    "%s.txt" % Date.parse(date).strftime("%y%m%d")
  end

  def print_date(date)
    if date == Date.today.prev_day
      'yesterday'
    else
      date
    end
  end

  def generate_output(lines)
    date = date_format(lines[0].split(' ')[0])
    result =
      lines.each_cons(2).reduce([date]) do |output, (line1, line2)|
        output << output_line(line1, line2)
      end
    result << output_line(lines.last, "#{date} 05:45:00 -0500 - #{lines.last.split(' - ')[1]}")
  end

  def output_line(line1, line2)
    date_info1, activity1 = line1.split(' - ')
    date_info2, _activity2 = line2.split(' - ')
    _date1, time1, _time_delta1 = date_info1.split(' ')
    _date2, time2, _time_delta2 = date_info2.split(' ')
    "#{time_format(time1)}-#{time_format(time2)}    - #{activity1}"
  end

  def date_format(str)
    year, month, day = str.split('-').map(&:to_i)
    Date.new(year, month, day).strftime('%-m/%-d/%y')
  end

  def time_format(str)
    str.split(':').first(2).join(':')
  end
end
